﻿#region License Information
/* HeuristicLab
 * Copyright (C) 2002-2011 Heuristic and Evolutionary Algorithms Laboratory (HEAL)
 *
 * This file is part of HeuristicLab.
 *
 * HeuristicLab is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * HeuristicLab is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with HeuristicLab. If not, see <http://www.gnu.org/licenses/>.
 */
#endregion

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Xml;
using HeuristicLab.DataImporter.Data;
using HeuristicLab.DataImporter.Data.CommandBase;
using HeuristicLab.DataImporter.Data.Model;
using HeuristicLab.Persistence.Default.CompositeSerializers.Storable;


namespace HeuristicLab.DataImporter.Command {
  [StorableClass]
  [ViewableCommandInfoAttribute("New ColumnGroup", 0, ColumnGroupState.None, "ColumnGroup Commands", Position = 0)]
  public class AddNewColumnGroupCommand : DataSetCommandBase {
    [Storable]
    private string newColumnGroupName;

    private ColumnGroup newColumnGroup;

    private AddNewColumnGroupCommand()
      : base(null) {
    }

    public AddNewColumnGroupCommand(DataSet dataSet)
      : base(dataSet) {
      int i = 0;
      string columnGroupName = "New ColumnGroup " + i;
      while (dataSet.ColumnGroups.Any(cg => cg.Name == columnGroupName)) {
        i++;
        columnGroupName = "New ColumnGroup " + i;
      }
      this.newColumnGroupName = columnGroupName;
    }

    private AddNewColumnGroupCommand(DataSet dataSet, string name)
      : base(dataSet) {
      this.newColumnGroupName = name;
    }

    public override string Description {
      get { return "New column group"; }
    }

    public override void Execute() {
      base.Execute();
      this.newColumnGroup = new ColumnGroup(newColumnGroupName);
      this.DataSet.AddColumnGroup(newColumnGroup);
      this.newColumnGroup.Active = true;
      this.DataSet.FireChanged();
    }

    public override void UndoExecute() {
      base.UndoExecute();
      this.DataSet.RemoveColumnGroup(newColumnGroup);
      this.newColumnGroup = null;
      this.DataSet.FireChanged();
    }
  }
}